==> kadu_0.11.0.orig.tar.bz2: kadu-0.11.0/plugins/spellchecker/translations/spellchecker_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozmowa</translation>
    </message>
    <message>
        <source>SpellChecker</source>
        <translation>SpellChecker</translation>
    </message>
    <message>
        <source>Misspelled Words Marking Options</source>
        <translation>Opcje zaznaczania błędnych słów</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Kolor</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Pogrubienie</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursywa</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Podkreślenie</translation>
    </message>
    <message>
        <source>Spell Checker Options</source>
        <translation>Opcje sprawdzania pisowni</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignoruj wielkość liter</translation>
    </message>
    <message>
        <source>Spelling Suggestions Options</source>
        <translation>Opcje sugerowania wyrazów</translation>
    </message>
    <message>
        <source>Show suggestions</source>
        <translation>Pokazuj sugestie</translation>
    </message>
    <message>
        <source>Maximum number of suggested words</source>
        <translation>Maksymalna ilość sugerowanych słów</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Could not find dictionary for %1 language.</source>
        <translation>Nie można znaleźć słownika dla języka %1.</translation>
    </message>
    <message>
        <source>Details: %1.</source>
        <translation>Szczegóły: %1.</translation>
    </message>
    <message>
        <source>Move to &apos;Checked&apos;</source>
        <translation>Przenieś do &apos;Sprawdzane&apos;</translation>
    </message>
    <message>
        <source>Available languages</source>
        <translation>Dostępne języki</translation>
    </message>
    <message>
        <source>Move to &apos;Available languages&apos;</source>
        <translation>Przenieś do &apos;Dostępne języki&apos;</translation>
    </message>
    <message>
        <source>Checked</source>
        <translation>Sprawdzane</translation>
    </message>
</context>
</TS>

==> kadu_0.12.0.orig.tar.bz2: kadu-0.12.0/plugins/spellchecker/translations/spellchecker_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozmowa</translation>
    </message>
    <message>
        <source>SpellChecker</source>
        <translation>SpellChecker</translation>
    </message>
    <message>
        <source>Misspelled Words Marking Options</source>
        <translation>Opcje zaznaczania błędnych słów</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Kolor</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Pogrubienie</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursywa</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Podkreślenie</translation>
    </message>
    <message>
        <source>Spell Checker Options</source>
        <translation>Opcje sprawdzania pisowni</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignoruj wielkość liter</translation>
    </message>
    <message>
        <source>Spelling Suggestions Options</source>
        <translation>Opcje sugerowania wyrazów</translation>
    </message>
    <message>
        <source>Show suggestions</source>
        <translation>Pokazuj sugestie</translation>
    </message>
    <message>
        <source>Maximum number of suggested words</source>
        <translation>Maksymalna ilość sugerowanych słów</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Could not find dictionary for %1 language.</source>
        <translation>Nie można znaleźć słownika dla języka %1.</translation>
    </message>
    <message>
        <source>Move to &apos;Checked&apos;</source>
        <translation>Przenieś do &apos;Sprawdzane&apos;</translation>
    </message>
    <message>
        <source>Available languages</source>
        <translation>Dostępne języki</translation>
    </message>
    <message>
        <source>Move to &apos;Available languages&apos;</source>
        <translation>Przenieś do &apos;Dostępne języki&apos;</translation>
    </message>
    <message>
        <source>Checked</source>
        <translation>Sprawdzane</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Szczegóły</translation>
    </message>
</context>
</TS>
